@@ -30,8 +30,8 @@ import logging
 import socket
 import struct
 from enum import Enum
-from os import urandom
 from functools import lru_cache, partial
+from os import urandom
 from typing import (
     Any,
     Awaitable,
@@ -963,7 +963,14 @@ class Application(
             partial(self._join_callback, join_callback=join_callback), asyncio.Future()
         )
         await self.network_interface.import_node(
-            "/", self.uuid, self.dev_key, net_key, net_index, flags, self.iv_index, self.address,
+            "/",
+            self.uuid,
+            self.dev_key,
+            net_key,
+            net_index,
+            flags,
+            self.iv_index,
+            self.address,
         )
         return await self._join_complete.future
 
@@ -1019,9 +1026,12 @@ class Element(LocationMixin):
         for opcode in sum((list(model.OPCODES) for model in self.MODELS), []):
             models = [model for model in self.MODELS if opcode in model.OPCODES]
 
-            assert len(models) == 1, (
-                "Element #%d declares models %r with overlapping opcode %r"
-                % (index, models, opcode)
+            assert (
+                len(models) == 1
+            ), "Element #%d declares models %r with overlapping opcode %r" % (
+                index,
+                models,
+                opcode,
             )
 
         self._models = {
