@@ -21,6 +21,7 @@
 #
 import calendar
 import enum
+import math
 import time
 from datetime import datetime, timedelta, timezone
 
@@ -28,15 +29,16 @@ from construct import (
     Adapter,
     BitsInteger,
     BytesInteger,
-    Construct,
     Container,
     Flag,
+    Float32l,
     Int8ul,
+    Int16sl,
+    Int16ul,
+    Int24ul,
     Padding,
     StopIf,
     Struct,
-    stream_read,
-    stream_write,
     this,
 )
 
@@ -124,7 +126,62 @@ Time = NamedSelect(
 )
 
 
+class TimeZoneOffsetAdapter(Adapter):
+    """
+    Time Zone Offset is described in minutes, mesh format in 15-minute increments.
+    """
+
+    def _decode(self, obj, context, path):
+        return (obj - 0x40) * 15
+
+    def _encode(self, obj, context, path):
+        assert ((obj % 15) == 0)
+        return 0x40 + (obj // 15)
+
+
+class TAIUTCDeltaAdapter(Adapter):
+    """
+    TAI-UTC Delta is described in seconds encoded in signed integer, mesh format in signed integer with different offset
+    """
+
+    def _decode(self, obj, context, path):
+        return obj - 0xFF
+
+    def _encode(self, obj, context, path):
+        assert (obj > -255)
+        return obj + 0xFF
+
+
+class UncertaintyAdapter(Adapter):
+    """
+    TAI-UTC Delta is described in seconds encoded in float, mesh format is in centiseconds
+    """
+
+    def _decode(self, obj, context, path):
+        return round(obj / 100, 2)
+
+    def _encode(self, obj, context, path):
+        assert (obj < 2.6)
+        return math.floor(obj * 100)
+
+
 class TimeAdapter(Adapter):
+    _subcon = Struct(
+        "date" / Struct(
+            "year" / Int16ul,
+            "month" / Int8ul,
+            "day" / Int8ul,
+            "hour" / Int8ul,
+            "minute" / Int8ul,
+            "second" / Int8ul,
+            "microsecond" / Int24ul,
+            "time_zone_offset" / TimeZoneOffsetAdapter(Int16sl),
+        ),
+        "tai_utc_delta" / TAIUTCDeltaAdapter(Int16sl),
+        "time_authority" / Flag,
+        "uncertainty" / UncertaintyAdapter(Float32l),
+    )
+
     def _decode(self, obj, context, path):
         if obj["tai_seconds"] == 0:
             return Container(
@@ -147,6 +204,26 @@ class TimeAdapter(Adapter):
 
     def _encode(self, obj, context, path):
         passed_time: datetime = obj["date"]
+
+        if isinstance(passed_time, dict):  # capnproto message
+            time_zone = timedelta(minutes=passed_time["time_zone_offset"])
+            passed_time = datetime(
+                year=passed_time["year"],
+                month=passed_time["month"],
+                day=passed_time["day"],
+                hour=passed_time["hour"],
+                minute=passed_time["minute"],
+                second=passed_time["second"],
+                microsecond=passed_time["microsecond"],
+                tzinfo=timezone(time_zone)
+            )
+
+        if isinstance(obj["uncertainty"], float):
+            obj["uncertainty"] = timedelta(seconds=obj["uncertainty"])
+
+        if isinstance(obj["tai_utc_delta"], int):
+            obj["tai_utc_delta"] = timedelta(seconds=obj["tai_utc_delta"])
+
         total_time = passed_time.timestamp() - MESH_UNIX_EPOCH_DIFF - passed_time.utcoffset().total_seconds()
 
         return Container(
